@@ -2,10 +2,12 @@
 
 import csv
 import math
+from os import path
 from datetime import datetime
 from pathlib import Path
 import statistics as stats
 from timeit import default_timer as timer
+from prettytable import PrettyTable
 
 from src.tspf.Algorithms.Population import Population
 from src.tspf.Algorithms.GeneticAlgorithm import GeneticAlgorithm
